@@ -1,4 +1,4 @@
-# $Id: Thread.pm,v 1.11 2003/09/16 15:11:02 cvspub Exp $
+# $Id: Thread.pm,v 1.12 2003/09/21 18:20:12 cvspub Exp $
 package WWW::Google::Groups::Thread;
 use strict;
 
@@ -52,8 +52,10 @@ sub next_article {
 	my @mids;
         foreach my $link (@links){
 	    $self->{_agent}->get($self->{_server}.$link);
-	    foreach my $mlink (grep{!/rnum=/o}
-			       grep{/selm=/o}map{$_->url}$self->{_agent}->links){
+	    foreach my $mlink (grep{!m,^http://,io}
+			       grep{!/rnum=/o}
+			       grep{/selm=/o}
+			       map{$_->url}$self->{_agent}->links){
 		$mlink =~ /selm=(.+?)$/o;
 		push @mids, $1;
 	    }
